==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/qt4_docking_notify/qt4-docking-notify-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtGui/QSystemTrayIcon>

#include "qt4-docking-notify.h"

#include "qt4-docking-notify-plugin.h"

Qt4DockingNotifyPlugin::~Qt4DockingNotifyPlugin()
{
}

bool Qt4DockingNotifyPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)

	if (!QSystemTrayIcon::supportsMessages())
		return false;

	NotifierInstance = new Qt4Notify(this);

	return true;
}

void Qt4DockingNotifyPlugin::done()
{
	delete NotifierInstance;
	NotifierInstance = 0;
}

Q_EXPORT_PLUGIN2(qt4_docking_notify, Qt4DockingNotifyPlugin)

#include "moc_qt4-docking-notify-plugin.cpp"

==> kadu-2.1.tar.bz2: kadu-2.1/plugins/qt4_docking_notify/qt4-docking-notify-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011, 2013 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QtWidgets/QSystemTrayIcon>

#include "qt4-docking-notify.h"

#include "qt4-docking-notify-plugin.h"

Qt4DockingNotifyPlugin::~Qt4DockingNotifyPlugin()
{
}

bool Qt4DockingNotifyPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)

	if (!QSystemTrayIcon::supportsMessages())
		return false;

	NotifierInstance = new Qt4Notify(this);

	return true;
}

void Qt4DockingNotifyPlugin::done()
{
	delete NotifierInstance;
	NotifierInstance = 0;
}

Q_EXPORT_PLUGIN2(qt4_docking_notify, Qt4DockingNotifyPlugin)

#include "moc_qt4-docking-notify-plugin.cpp"
